@@ -8,10 +8,10 @@
 
 import warnings
 
-from peewee import (AutoField, BigAutoField, BigIntegerField, CharField,
-                    DeferredThroughModel, DoubleField, FloatField,
-                    ForeignKeyField, IntegerField, ManyToManyField, TextField)
-
+from peewee import (AutoField, BigAutoField, BigIntegerField,
+                    CharField, DeferredThroughModel, DoubleField,
+                    FixedCharField, FloatField, ForeignKeyField,
+                    IntegerField, ManyToManyField, TextField)
 from playhouse.postgres_ext import ArrayField
 
 from sdssdb.exceptions import SdssdbUserWarning
@@ -63,6 +63,15 @@ class Catalog(CatalogdbModel):
         table_name = 'catalog'
         use_reflection = False
 
+    @property
+    def run_id(self):
+        """Returns the ``run_id`` for this object."""
+
+        RUN_N_BITS = 11  # Number of left-most bits reserved for the run_id
+        run_id_mask = (2**RUN_N_BITS - 1) << (64 - RUN_N_BITS)
+
+        return (self.catalogid & run_id_mask) >> (64 - RUN_N_BITS)
+
 
 class AllWise(CatalogdbModel):
 
@@ -73,6 +82,46 @@ class AllWise(CatalogdbModel):
         table_name = 'allwise'
 
 
+class EROSITASupersetAGN(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'erosita_superset_agn'
+
+
+class EROSITASupersetClusters(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'erosita_superset_clusters'
+
+
+class EROSITASupersetStars(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'erosita_superset_stars'
+
+
+class EROSITASupersetCompactobjects(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'erosita_superset_compactobjects'
+
+
+class ElbadryRix(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'elbadry_rix'
+
+
 class TwoMassPSC(CatalogdbModel):
 
     pts_key = IntegerField(primary_key=True)
@@ -102,6 +151,22 @@ class Gaia_DR2(CatalogdbModel):
         table_name = 'gaia_dr2_source'
 
 
+class Gaia_EDR3(CatalogdbModel):
+
+    source_id = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'gaia_edr3_source'
+
+
+class Gaia_DR2_Neighbourhood(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'gaia_dr2_neighbourhood'
+
+
 class Gaia_DR2_Clean(CatalogdbModel):
 
     source_id = BigIntegerField(primary_key=True)
@@ -132,6 +197,94 @@ class KeplerInput_DR10(CatalogdbModel):
         table_name = 'kepler_input_10'
 
 
+class CantatGaudinTable1(CatalogdbModel):
+    # BigIntegerField is fine even though table column pkey
+    # is a bigserial column
+    pkey = BigIntegerField(primary_key=True)
+    cluster = CharField()
+    source_id = BigIntegerField()
+
+    class Meta:
+        table_name = 'cantat_gaudin_table1'
+
+
+class CantatGaudinNodup(CatalogdbModel):
+    # BigIntegerField is fine even though table column pkey
+    # is a bigserial column
+    pkey = BigIntegerField(primary_key=True)
+
+    gaiadr2_fk = ForeignKeyField(
+        model=Gaia_DR2,  # remote model
+        field='source_id',  # remote column name
+        column_name='gaiadr2',  # local column name
+        object_id_name='gaiadr2',  # same as local column name
+        backref='+')  # '+' means do not create backref
+
+    cluster_fk = ForeignKeyField(
+        model=CantatGaudinTable1,  # remote model
+        field='cluster',  # remote column name
+        column_name='cluster',  # local column name
+        object_id_name='cluster',  # same as local column name
+        backref='+')  # '+' means do not create backref
+
+    class Meta:
+        table_name = 'cantat_gaudin_nodup'
+
+
+class Sagitta(CatalogdbModel):
+
+    source_id = BigIntegerField(primary_key=True)
+
+    gaia_dr2 = ForeignKeyField(
+        model=Gaia_DR2,
+        field='source_id',
+        column_name='source_id',
+        object_id_name='source_id',
+        backref='+')
+
+    class Meta:
+        table_name = 'sagitta'
+
+
+class SDSSV_Plateholes_Meta(CatalogdbModel):
+
+    yanny_uid = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'sdssv_plateholes_meta'
+
+
+class SDSSV_Plateholes(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    yanny_uid_fk = ForeignKeyField(
+        model=SDSSV_Plateholes_Meta,  # remote model
+        field='yanny_uid',  # remote column name
+        column_name='yanny_uid',  # local column name
+        object_id_name='yanny_uid',  # same as local column name
+        backref='+')  # '+' means do not create backref
+
+    class Meta:
+        table_name = 'sdssv_plateholes'
+
+
+class SDSSV_BOSS_Conflist(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'sdssv_boss_conflist'
+
+
+class SDSSV_BOSS_SPALL(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'sdssv_boss_spall'
+
+
 class SDSS_DR13_PhotoObj(CatalogdbModel):
 
     objid = BigIntegerField(primary_key=True)
@@ -268,8 +421,8 @@ class TIC_v8(CatalogdbModel):
 
     id = BigIntegerField(primary_key=True)
 
-    tycho2 = ForeignKeyField(Tycho2, field='designation',
-                             column_name='tyc', object_id_name='tyc',
+    tycho2 = ForeignKeyField(Tycho2, field='tycid',
+                             column_name='tycho2', object_id_name='tycho2',
                              backref='tic')
 
     twomass_psc = ForeignKeyField(TwoMassPSC, field='designation',
@@ -296,6 +449,66 @@ class TIC_v8(CatalogdbModel):
         table_name = 'tic_v8'
 
 
+class TIC_v8_Extended(TIC_v8):
+
+    class Meta:
+        table_name = 'tic_v8_extended'
+
+
+class MWM_TESS_OB(CatalogdbModel):
+
+    gaia_dr2_id = BigIntegerField(primary_key=True)
+
+    gaiadr2_fk = ForeignKeyField(
+        model=Gaia_DR2,  # remote model
+        field='source_id',  # remote column name
+        column_name='gaia_dr2_id',  # local column name
+        object_id_name='gaia_dr2_id',  # same as local column name
+        backref='+')  # '+' means do not create backref
+
+    class Meta:
+        table_name = 'mwm_tess_ob'
+
+
+class Twoqz_sixqz(CatalogdbModel):
+    # BigIntegerField is fine even though table column pkey
+    # is a bigserial column
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'twoqz_sixqz'
+
+
+class Zari18pms(CatalogdbModel):
+
+    source = BigIntegerField(primary_key=True)
+
+    gaia_dr2 = ForeignKeyField(
+        model=Gaia_DR2,
+        field='source_id',
+        column_name='source',
+        object_id_name='source',
+        backref='+')
+
+    class Meta:
+        table_name = 'zari18pms'
+
+
+class Zari18ums(CatalogdbModel):
+
+    source = BigIntegerField(primary_key=True)
+
+    gaia_dr2 = ForeignKeyField(
+        model=Gaia_DR2,
+        field='source_id',
+        column_name='source',
+        object_id_name='source',
+        backref='+')
+
+    class Meta:
+        table_name = 'zari18ums'
+
+
 class Legacy_Survey_DR8(CatalogdbModel):
 
     ls_id = BigIntegerField(primary_key=True)
@@ -551,7 +764,7 @@ class Gaia_DR2_WD(CatalogdbModel):
 
 class CatWISE(CatalogdbModel):
 
-    source_id = BigIntegerField(primary_key=True)
+    source_id = FixedCharField(primary_key=True)
 
     class Meta:
         table_name = 'catwise'
@@ -559,12 +772,20 @@ class CatWISE(CatalogdbModel):
 
 class CatWISEReject(CatalogdbModel):
 
-    source_id = BigIntegerField(primary_key=True)
+    source_id = FixedCharField(primary_key=True)
 
     class Meta:
         table_name = 'catwise_reject'
 
 
+class CatWISE2020(CatalogdbModel):
+
+    source_id = FixedCharField(primary_key=True)
+
+    class Meta:
+        table_name = 'catwise2020'
+
+
 class Watchdog(CatalogdbModel):
 
     gaia_source_id = BigIntegerField(primary_key=True)
@@ -813,10 +1034,12 @@ class GLIMPSE(CatalogdbModel):
 
 
 class GLIMPSE360(CatalogdbModel):
-
+    # BigIntegerField is fine even though table column pkey
+    # is a bigserial column
     pkey = BigIntegerField(primary_key=True)
 
-    twomass = ForeignKeyField(TwoMassPSC, field='pts_key',
+    twomass = ForeignKeyField(model=TwoMassPSC,
+                              field='pts_key',
                               column_name='tmass_cntr',
                               backref='glimpse360_targets')
 
@@ -954,6 +1177,19 @@ class TESS_TOI(CatalogdbModel):
         table_name = 'tess_toi'
 
 
+class TESS_TOI_v05(CatalogdbModel):
+
+    pk = BigIntegerField(primary_key=True)
+
+    tic = ForeignKeyField(TIC_v8,
+                          column_name='ticid',
+                          object_id_name='ticid',
+                          backref='+')
+
+    class Meta:
+        table_name = 'tess_toi_v05'
+
+
 class XMM_OM_SUSS_4_1(CatalogdbModel):
 
     pk = BigIntegerField(primary_key=True)
@@ -1014,6 +1250,14 @@ class BHM_RM_v0_2(BHM_RM_v0):
     pass
 
 
+class BHM_RM_Tweaks(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'bhm_rm_tweaks'
+
+
 class Gaia_DR2_RUWE(CatalogdbModel):
 
     gaia = ForeignKeyField(Gaia_DR2,
@@ -1115,6 +1359,14 @@ class Skies_v1(CatalogdbModel):
         table_name = 'skies_v1'
 
 
+class SuperCosmos(CatalogdbModel):
+
+    objid = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'supercosmos'
+
+
 _Gaia_DR2_TwoMass_Deferred.set_model(Gaia_DR2_TwoMass_Best_Neighbour)
 _APOGEE_Star_Visit_Deferred.set_model(SDSS_DR16_APOGEE_Star_AllVisit)
 
